@@ -30,5 +30,10 @@ def delete_all_contents_in_directory(folder_path: str) -> None:
 def directory_exists(folder_path: str) -> bool:
     return os.path.exists(folder_path)
 
+
 def directory_empty(folder_path: str) -> bool:
     return len(os.listdir(folder_path)) == 0
+
+
+def file_exists(file_path: str) -> bool:
+    return os.path.isfile(file_path)
