@@ -1,29 +1,19 @@
-from typing import Optional, List, Any
+from typing import Optional, List, Any, Dict
 
 from pydantic import BaseModel
 
-from deeploy.common import to_lower_camel
-from deeploy.enums import ModelType, ExplainerType, PredictionMethod
+from deeploy.common.functions import to_lower_camel
 
 
 class Deployment(BaseModel):
-    commit_id: str
     name: str
+    active_version: Optional[Dict]
     workspace_id: str
     description: Optional[str]
     example_input: Optional[List[Any]]
     example_output: Optional[List[Any]]
-    model_type: ModelType
-    model_class_name: Optional[str]
-    method: PredictionMethod
-    model_serverless: bool
-    explainer_type: Optional[ExplainerType]
-    explainer_serverless: Optional[bool]
     status: int
-    is_archived: bool
-    s3_link: str
     owner_id: str
-    repository_id: str
     kf_serving_id: Optional[str]
     public_url: Optional[str]
     id: str
@@ -40,23 +30,17 @@ class DeployOptions(BaseModel):
 
     Attributes:
       name: name of the deployment
-      model_serverless: boolean indicating whether to deploy the model in 
+      model_serverless: boolean indicating whether to deploy the model in
         a serverless fashion. Defaults to False
-      explainer_serverless: boolean indicating whether to deploy the model in 
+      explainer_serverless: boolean indicating whether to deploy the model in
         a serverless fashion. Defaults to False
-      method: string indication which prediction function to use. Only applicable
-        to sklearn and xgboost models. Defaults to 'predict'
       description: string with the description of the deployment
       example_input: list of example input parameters for the model
       example_output: list of example output for the model
-      model_class_name: string indicating the name of the class containing a 
-        PyTorch model.
     """
     name: str
     model_serverless = False
     explainer_serverless = False
-    method = 'predict'
     description: Optional[str]
     example_input: Optional[List[Any]]
     example_output: Optional[List[Any]]
-    model_class_name: Optional[str]
