@@ -1,9 +1,8 @@
-from typing import List, Optional
+from typing import Optional
 
 from pydantic import BaseModel
 
-from .commit import Commit
-from deeploy.common import to_lower_camel
+from deeploy.common.functions import to_lower_camel
 
 
 class Repository(BaseModel):
@@ -16,7 +15,6 @@ class Repository(BaseModel):
     git_ssh_pull_link: str
     created_at: str
     updated_at: str
-    commits: List[Commit]
 
     class Config:
         alias_generator = to_lower_camel
